@@ -174,6 +174,20 @@ GST_START_TEST (test_from_string)
   ASSERT_WARNING (structure = gst_structure_from_string (s, NULL));
   fail_if (structure == NULL, "Could not get structure from string %s", s);
   gst_structure_free (structure);
+
+  /* make sure we handle \ as last character in various things, run with valgrind */
+  s = "foo,test=\"foobar\\";
+  structure = gst_structure_from_string (s, NULL);
+  fail_unless (structure == NULL);
+  s = "\\";
+  structure = gst_structure_from_string (s, NULL);
+  fail_unless (structure == NULL);
+  s = "foobar,test\\";
+  structure = gst_structure_from_string (s, NULL);
+  fail_unless (structure == NULL);
+  s = "foobar,test=(string)foo\\";
+  structure = gst_structure_from_string (s, NULL);
+  fail_unless (structure == NULL);
 }
 
 GST_END_TEST;
@@ -210,7 +224,7 @@ GST_START_TEST (test_to_from_string)
 
   fail_unless (st2 != NULL);
 
-  /* need to put stuctures into caps to compare */
+  /* need to put structures into caps to compare */
   caps1 = gst_caps_new_empty ();
   gst_caps_append_structure (caps1, st1);
   caps2 = gst_caps_new_empty ();
@@ -258,7 +272,7 @@ GST_START_TEST (test_string_properties)
 
   fail_unless (st2 != NULL);
 
-  /* need to put stuctures into caps to compare */
+  /* need to put structures into caps to compare */
   caps1 = gst_caps_new_empty ();
   gst_caps_append_structure (caps1, st1);
   caps2 = gst_caps_new_empty ();
@@ -284,24 +298,26 @@ GST_START_TEST (test_structure_new)
   gboolean bool;
   gint num, den;
   GstClockTime clocktime;
+  guint64 uint64;
 
   s = gst_structure_new ("name",
       "key", G_TYPE_STRING, "value",
       "bool", G_TYPE_BOOLEAN, TRUE,
       "fraction", GST_TYPE_FRACTION, 1, 5,
-      "clocktime", GST_TYPE_CLOCK_TIME, GST_CLOCK_TIME_NONE, NULL);
+      "clocktime", GST_TYPE_CLOCK_TIME, GST_CLOCK_TIME_NONE,
+      "uint64", G_TYPE_UINT64, (guint64) 1234, NULL);
 
   fail_unless (gst_structure_get_field_type (s, "unknown") == G_TYPE_INVALID);
   /* test setting a different name */
   gst_structure_set_name (s, "newname");
   fail_unless (strcmp (gst_structure_get_string (s, "key"), "value") == 0);
   fail_unless (gst_structure_has_field (s, "key"));
-  fail_unless_equals_int (gst_structure_n_fields (s), 4);
+  fail_unless_equals_int (gst_structure_n_fields (s), 5);
   /* test removing a field */
   gst_structure_remove_field (s, "key");
   fail_if (gst_structure_get_string (s, "key"));
   fail_if (gst_structure_has_field (s, "key"));
-  fail_unless_equals_int (gst_structure_n_fields (s), 3);
+  fail_unless_equals_int (gst_structure_n_fields (s), 4);
 
   fail_unless (gst_structure_get_boolean (s, "bool", &bool));
   fail_unless (bool);
@@ -313,6 +329,9 @@ GST_START_TEST (test_structure_new)
   fail_unless (gst_structure_get_clock_time (s, "clocktime", &clocktime));
   fail_unless_equals_uint64 (clocktime, GST_CLOCK_TIME_NONE);
 
+  fail_unless (gst_structure_get_uint64 (s, "uint64", &uint64));
+  fail_unless_equals_uint64 (uint64, 1234);
+
   gst_structure_free (s);
 
   domain = g_quark_from_static_string ("test");
